You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@nuttx.apache.org by GitBox <gi...@apache.org> on 2022/09/12 16:11:30 UTC

[GitHub] [incubator-nuttx] hartmannathan commented on pull request #7076: Remove duplicate calls and optimize compilation speed

hartmannathan commented on PR #7076:
URL: https://github.com/apache/incubator-nuttx/pull/7076#issuecomment-1243967823

   It works for me and I do see a speedup -- about 10 seconds saved on a full build (1 minute 15 seconds before, reduced down to 1 minute 5 seconds), and 5 seconds saved on a partial build (10 seconds before, reduced down to 5 seconds after). It is amazing how much time is wasted spawning a subshell!!


-- 
This is an automated message from the Apache Git Service.
To respond to the message, please log on to GitHub and use the
URL above to go to the specific comment.

To unsubscribe, e-mail: commits-unsubscribe@nuttx.apache.org

For queries about this service, please contact Infrastructure at:
users@infra.apache.org